@@ -44,7 +44,7 @@
 #endif
 
 
-#define HE5_HDFEOSVERSION "1.15"
+#define HE5_HDFEOSVERSION "1.16"
 
 #define H5_USE_16_API 1
 
@@ -493,7 +493,10 @@ herr_t   HE5_EHchkfid(hid_t fid, const char *name, hid_t *HDFfid, hid_t *grpID,
 herr_t   HE5_EHidinfo(hid_t fid, hid_t *HDFfid, hid_t *gid);
 long     HE5_EHattrcat(hid_t fid,   char *grpname, char *objectlist, long *strbufsize);
 long     HE5_EHinquire(const char *filename, char *grpname, char *objectlist, long *strbufsize);
-hsize_t HE5_EHset_error_on(int flag, int err_level);
+hsize_t  HE5_EHset_error_on(int flag, int err_level);
+herr_t   HE5_EHwritemeta(hid_t fid, const char *MetadataName, char *metabuff);
+herr_t   HE5_EHreadmeta(hid_t fid, const char *MetadataName, char *metabufout, long *bufferSize);
+long HE5_EHinqmetadatas(hid_t fid, char *metadatanames, long *strbufsize);
 
 /* PROTOTYPES: functions to turn HDFEOS5 error printing off */
 herr_t HE5_EHprint(char *errbuf, const char *file, unsigned line);
@@ -513,6 +516,7 @@ long     HE5_EHcntOBJECT(char *metabuf[]);
 long     HE5_EHcntGROUP(char *metabuf[]);
 herr_t   HE5_EHattr( hid_t attgrpID, const char *attrname, hid_t ntype, hsize_t count[], char *wrcode, void *datbuf);
 herr_t   HE5_EHattrinfo( hid_t attgrpID, const char *attrname, hid_t ntype[], hsize_t *count);
+herr_t   HE5_EHattrinfo2( hid_t attgrpID, const char *attrname, hid_t ntype[], hsize_t *count,  hsize_t *size);
 long     HE5_EHdatasetcat(hid_t fid,  char *grpname, char *objectlist, long  *strbufsize);
 int      HE5_EHobj_info(hid_t loc_id, const char *name, void *opdata);
 
@@ -520,6 +524,8 @@ int      HE5_EHobj_info(hid_t loc_id, const char *name, void *opdata);
 
 long     HE5_EHparsestr(const char *instring, char delim, char *pntr[], size_t len[]);
 long     HE5_EHstrwithin(char *target, char *search, char delim);
+long     HE5_EHstrwithin_index(char *target, char *search, char delim,int* index_found);
+
 herr_t   HE5_EHloadliststr(char *ptr[], long nentries, char *liststr, char delim);
 double   HE5_EHconvAng(double inAngle, int code);
 herr_t   HE5_EHrevflds(char *dimlist, char *revdimlist);
@@ -530,6 +536,7 @@ hid_t    HE5_EHconvdatatype(int fortdatatype);
 herr_t   HE5_EHwriteglbattr(hid_t fid, const char *attrname, hid_t ntype, hsize_t  count[], void *datbuf);
 herr_t   HE5_EHreadglbattr(hid_t fid, const char *attrname, void * datbuf);
 herr_t   HE5_EHglbattrinfo(hid_t fid, const char *attrname, hid_t *ntype, hsize_t *count);
+herr_t   HE5_EHglbattrinfo2(hid_t fid, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 long     HE5_EHinqglbattrs(hid_t fid, char *attrnames, long *strbufsize);
 herr_t   HE5_EHinqglbdatatype(hid_t fid, const char *attrname, hid_t *dtype, H5T_class_t *classid, H5T_order_t *order, size_t *size);
 int      HE5_szip_can_encode(void );
@@ -629,6 +636,10 @@ herr_t  HE5_SWattrinfo(hid_t swathID, const char *attrname, hid_t *ntype, hsize_
 herr_t  HE5_SWgrpattrinfo(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t  HE5_SWgeogrpattrinfo(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t  HE5_SWlocattrinfo(hid_t swathID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
+herr_t  HE5_SWattrinfo2(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
+herr_t  HE5_SWgrpattrinfo2(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
+herr_t  HE5_SWgeogrpattrinfo2(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
+herr_t  HE5_SWlocattrinfo2(hid_t swathID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 herr_t  HE5_SWinqdatatype(hid_t swathID, const char *fieldname, const char *attrname, int group, hid_t *dtype, H5T_class_t *classid, H5T_order_t *order, size_t *size);
 long    HE5_SWinqdims(hid_t swathID, char *dimnames, hsize_t dims[]);
 long    HE5_SWinqmaps(hid_t swathID, char *dimmaps, long offset[], long increment[]);
@@ -651,6 +662,7 @@ long    HE5_SWinqgfldalias(hid_t swathID, char *fldalias, long *strbufsize);
 long    HE5_SWgetaliaslist(hid_t swathID, int fldgroup, char *aliaslist, long *strbufsize);
 long    HE5_SWgetdimscale(hid_t swathID, char *fieldname, char *dimname, hsize_t *dimsize, hid_t *numbertype, void * databuff);
 herr_t  HE5_SWdscaleattrinfo(hid_t swathID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
+herr_t  HE5_SWdscaleattrinfo2(hid_t swathID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 herr_t  HE5_SWreaddscaleattr(hid_t swathID, const char *fieldname, const char *attrname, void *datbuf);
 long    HE5_SWinqdscaleattrs(hid_t swathID, const char *fieldname, char *attrnames, long *strbufsize);
 
@@ -682,6 +694,7 @@ herr_t  HE5_PRinfo(hid_t swathID, const char *profname, int *rank, hsize_t dims[
 herr_t  HE5_PRwritegrpattr(hid_t swathID, const char *attrname, hid_t ntype, hsize_t count[], void *datbuf);
 herr_t  HE5_PRreadgrpattr(hid_t swathID, const char *attrname, void *datbuf);
 herr_t  HE5_PRgrpattrinfo(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count);
+herr_t  HE5_PRgrpattrinfo2(hid_t swathID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 long    HE5_PRinqgrpattrs(hid_t swathID, char *attrnames, long *strbufsize);
 
 
@@ -768,6 +781,9 @@ int      HE5_GDinqdims(hid_t gridID, char *dimnames, hsize_t  dims[]);
 herr_t   HE5_GDattrinfo(hid_t gridID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t   HE5_GDgrpattrinfo(hid_t gridID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t   HE5_GDlocattrinfo(hid_t gridID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
+herr_t   HE5_GDattrinfo2(hid_t gridID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
+herr_t   HE5_GDgrpattrinfo2(hid_t gridID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
+herr_t   HE5_GDlocattrinfo2(hid_t gridID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 long     HE5_GDinqattrs(hid_t gridID, char *attrnames, long *strbufsize);
 long     HE5_GDinqgrpattrs(hid_t gridID, char *attrnames, long *strbufsize);
 long     HE5_GDinqlocattrs(hid_t gridID, const char *fieldname, char *attrnames, long *strbufsize);
@@ -781,6 +797,7 @@ long     HE5_GDgetaliaslist(hid_t gridID, int fldgroup, char *aliaslist, long *s
 long     HE5_GDgetdimscale(hid_t gridID, char *fieldname, char *dimname, hsize_t *dimsize, hid_t *numbertype, void * databuff);
 herr_t   HE5_GDwritedscaleattr(hid_t gridID, const char *fieldname, const char *attrname, hid_t numtype, hsize_t  count[],  void *datbuf);
 herr_t   HE5_GDdscaleattrinfo(hid_t gridID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
+herr_t   HE5_GDdscaleattrinfo2(hid_t gridID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 herr_t   HE5_GDreaddscaleattr(hid_t gridID, const char *fieldname, const char *attrname, void *datbuf);
 long     HE5_GDinqdscaleattrs(hid_t gridID, const char *fieldname, char *attrnames, long *strbufsize);
 
@@ -788,7 +805,7 @@ long     HE5_GDinqdscaleattrs(hid_t gridID, const char *fieldname, char *attrnam
 
 hid_t    HE5_GDdefboxregion(hid_t gridID, double cornerlon[], double cornerlat[]);
 hid_t    HE5_GDdefvrtregion(hid_t gridID, hid_t regionID, char *vertObj, double range[]);
-herr_t   HE5_GDdeftimeperiod(hid_t gridID, hid_t periodID, double starttime, double stoptime);
+hid_t   HE5_GDdeftimeperiod(hid_t gridID, hid_t periodID, double starttime, double stoptime);
 herr_t   HE5_GDextractregion(hid_t gridID, hid_t regionID, const char *fieldname, void *buffer);
 hid_t    HE5_GDdupregion(hid_t oldregionID);
 herr_t   HE5_GDgetpixels(hid_t gridID, long nLonLat, double lonVal[], double latVal[], long pixRow[], long pixCol[]);
@@ -864,6 +881,9 @@ herr_t   HE5_PTgetrecnums(hid_t pointID, int inlevel, int outlevel, hsize_t inNr
 herr_t   HE5_PTattrinfo(hid_t pointID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t   HE5_PTgrpattrinfo(hid_t pointID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t   HE5_PTlocattrinfo(hid_t pointID, const char *levelname, const char *attrname, hid_t *ntype, hsize_t *count);
+herr_t   HE5_PTattrinfo2(hid_t pointID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
+herr_t   HE5_PTgrpattrinfo2(hid_t pointID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
+herr_t   HE5_PTlocattrinfo2(hid_t pointID, const char *levelname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 long     HE5_PTinqattrs(hid_t pointID, char *attrnames, long *strbufsize);
 long     HE5_PTinqgrpattrs(hid_t pointID, char *attrnames, long *strbufsize);
 long     HE5_PTinqlocattrs(hid_t pointID, const char *levelname, char *attrnames, long *strbufsize);
@@ -911,8 +931,8 @@ herr_t  HE5_ZAreadgrpattr(hid_t zaID, const char *attrname, void *datbuf);
 herr_t  HE5_ZAreadlocattr(hid_t zaID, const char *fieldname, const char *attrname, void *datbuf);
 herr_t  HE5_ZAwrite(hid_t zaID, char *za_name, const hssize_t start[], const hsize_t stride[], const hsize_t count[],  void *datbuf);
 herr_t  HE5_ZAread(hid_t zaID, char *za_name, const hssize_t start[], const hsize_t stride[], const hsize_t count[],  void *datbuf);
-herr_t HE5_ZAreaddscaleattr(hid_t zaID, const char *fieldname, const char *attrname, void *datbuf);
-herr_t HE5_ZAwritedscaleattr(hid_t zaID, const char *fieldname, const char *attrname, hid_t numtype, hsize_t  count[],  void *datbuf); 
+herr_t  HE5_ZAreaddscaleattr(hid_t zaID, const char *fieldname, const char *attrname, void *datbuf);
+herr_t  HE5_ZAwritedscaleattr(hid_t zaID, const char *fieldname, const char *attrname, hid_t numtype, hsize_t  count[],  void *datbuf); 
  
 /* Inquiry routines */
  
@@ -923,6 +943,9 @@ herr_t  HE5_ZAcompinfo(hid_t zaID, char *fieldname, int *compcode, int compparm[
 herr_t  HE5_ZAattrinfo(hid_t zaID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t  HE5_ZAgrpattrinfo(hid_t zaID, const char *attrname, hid_t *ntype, hsize_t *count);
 herr_t  HE5_ZAlocattrinfo(hid_t zaID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
+herr_t  HE5_ZAattrinfo2(hid_t zaID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
+herr_t  HE5_ZAgrpattrinfo2(hid_t zaID, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
+herr_t  HE5_ZAlocattrinfo2(hid_t zaID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
 herr_t  HE5_ZAinqdatatype(hid_t zaID, const char *fieldname, const char *attrname, int group, hid_t *dtype, H5T_class_t *classid, H5T_order_t *order, size_t *size);
 long    HE5_ZAinqdims(hid_t zaID, char *dimnames, hsize_t dims[]);
 long    HE5_ZAinquire(hid_t zaID, char *za_name_list, int rank[], hid_t dtype[]);
@@ -936,8 +959,9 @@ herr_t  HE5_ZAaliasinfo(hid_t zaID, int fldgroup, const char *aliasname, int *le
 long    HE5_ZAinqfldalias(hid_t zaID, char *fldalias, long *strbufsize);
 herr_t  HE5_ZAchunkinfo(hid_t zaID, char *fieldname, int *ndims, hsize_t dims[]);
 long    HE5_ZAgetaliaslist(hid_t zaID, int fldgroup, char *aliaslist, long *strbufsize);
-herr_t HE5_ZAdscaleattrinfo(hid_t zaID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
-long HE5_ZAinqdscaleattrs(hid_t zaID, const char *fieldname, char *attrnames, long *strbufsize);
+herr_t  HE5_ZAdscaleattrinfo(hid_t zaID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count);
+herr_t  HE5_ZAdscaleattrinfo2(hid_t zaID, const char *fieldname, const char *attrname, hid_t *ntype, hsize_t *count, hsize_t *size);
+long    HE5_ZAinqdscaleattrs(hid_t zaID, const char *fieldname, char *attrnames, long *strbufsize);
 
 /*
  *******************************
@@ -967,15 +991,3 @@ herr_t  HE5_ZAreadexternal(hid_t zaID, int fldgroup, const char *fieldname, void
 
 
 #endif  /* #ifndef HE5_HDFEOSDEF_H_ */
-
-
-
-
-
-
-
-
-
-
-
-
