@@ -102,8 +102,17 @@ c----------------------------------------------------------------------------
       real*8		upleftpt(2), lowrtpt(2),corlon(2),corlat(2)
 
       character*80	grdnames, dimname, fldlist, attrlist
-      character*80	compcodestring, maxdimname
+      character*80	maxdimname
+      integer*4	    	compcodestring
       
+      nt(1)= 0      
+      nt(2)= 0      
+      nt(3)= 0      
+      nt(4)= 0
+      rk(1)= 0
+      rk(2)= 0
+      rk(3)= 0
+      rk(4)= 0
 
       index1 = 0
       index2 = 0
@@ -191,7 +200,7 @@ c
   240 format('***********Passed Test*********')
 
 
-      open(unit=10,file='testgrid.txt', status = "UNKNOWN")
+      open(unit=10,file='testgrid_f.txtout', status = "UNKNOWN")
 
       write(*,*)'Testing Grid FORTRAN 77 interface '
       write(*,*)'=================================='
@@ -206,7 +215,7 @@ c
       write(10,*)'======================'
       write(*,*)'Testing he5_gdopen... '
       write(*,*)'======================'
-      gdfid2 = he5_gdopen("grid2.he5",HE5F_ACC_TRUNC)
+      gdfid2 = he5_gdopen("grid2fortran64",HE5F_ACC_TRUNC)
       if (gdfid2 .lt. zero) then
          write(*,231)
          write(10,231)
@@ -216,15 +225,15 @@ c
          write(*,240)
          write(10,*)' '
          write(10,240)
-         write(10,*)'gdfid2 = he5_gdopen("grid2.he5",HE5F_ACC_TRUNC)'
+         write(10,*)'gdfid2 = he5_gdopen("grid2fortran64",HE5F_ACC_TRUNC)'
          write(10,*)'Value returned by gdopen ', gdfid2
-         write(*,*)'gdfid2 = he5_gdopen("grid2.he5",HE5F_ACC_TRUNC)'
+         write(*,*)'gdfid2 = he5_gdopen("grid2fortran64",HE5F_ACC_TRUNC)'
          write(*,*)'Value returned by gdopen ', gdfid2
       endif
       write(*,*)' '
       write(10,*)' '
 
-      gdfid = he5_gdopen('grid.he5',HE5F_ACC_TRUNC)
+      gdfid = he5_gdopen('gridfortran64',HE5F_ACC_TRUNC)
       if (gdfid .lt. zero) then
          write(*,230)
          write(10,230)
@@ -234,11 +243,11 @@ c
          write(*,240)
          write(10,*)' '
          write(10,240)
-         write(*,*)'Opening file grid.he5'
-         write(10,*)'Opening file grid.he5'
-         write(10,*) 'gdfid = he5_gdopen("grid.he5",HE5F_ACC_TRUNC)'
+         write(*,*)'Opening file gridfortran64'
+         write(10,*)'Opening file gridfortran64'
+         write(10,*) 'gdfid = he5_gdopen("gridfortran64",HE5F_ACC_TRUNC)'
          write(10,*) 'File id returned from gdopen ', gdfid
-         write(*,*) 'gdfid = he5_gdopen("grid.he5",HE5F_ACC_TRUNC)'
+         write(*,*) 'gdfid = he5_gdopen("gridfortran64",HE5F_ACC_TRUNC)'
          write(*,*) 'File id returned from gdopen ', gdfid
       endif
       write(10,*)' '
@@ -1394,7 +1403,7 @@ c
       write(*,*)' '
 
       
-      gdfid = he5_gdopen('grid.he5',HE5F_ACC_RDWR)
+      gdfid = he5_gdopen('gridfortran64',HE5F_ACC_RDWR)
       if (gdfid .lt. zero) then
          write(*,230)
          write(10,230)
@@ -1404,8 +1413,8 @@ c
          write(*,240)
          write(10,*)' '
          write(10,240)
-         write(*,*)'gdfid = he5_gdopen("grid.he5",HE5F_ACC_RDWR)'
-         write(10,*)'gdfid = he5_gdopen("grid.he5",HE5F_ACC_RDWR)'
+         write(*,*)'gdfid = he5_gdopen("gridfortran64",HE5F_ACC_RDWR)'
+         write(10,*)'gdfid = he5_gdopen("gridfortran64",HE5F_ACC_RDWR)'
          write(*,*)'Grid file id returned by gdopen ',gdfid
          write(10,*)'Grid file id returned by gdopen ',gdfid
       endif
@@ -1438,7 +1447,7 @@ c
       write(*,*)'Testing he5_gdinqgrid... '
       write(*,*)'=========================='
 
-      lstatus = he5_gdinqgrid('grid.he5',grdnames,strbufsize)
+      lstatus = he5_gdinqgrid('gridfortran64',grdnames,strbufsize)
       if (lstatus .lt. zero) then
          write(*,230)
          write(10,230)
@@ -1448,12 +1457,12 @@ c
          write(*,240)
          write(10,*)' '
          write(10,240)
-         write(*,*)'lstatus = he5_gdinqgrid("grid.he5",grdnames,
+         write(*,*)'lstatus = he5_gdinqgrid("gridfortran64",grdnames,
      1strbufsize)'
          write(*,*)'Names of grids ',grdnames
          write(*,*)'Number of grids ',lstatus
          write(*,*)'Size of names of grids ',strbufsize
-         write(10,*)'lstatus = he5_gdinqgrid("grid.he5",grdnames,
+         write(10,*)'lstatus = he5_gdinqgrid("gridfortran64",grdnames,
      1strbufsize)'
          write(10,*)'Names of grids ',grdnames
          write(10,*)'Number of grids ',lstatus
